@@ -29,8 +29,8 @@ def main() -> None:
     with open(args.schema_path) as file:
         schema = json.load(file)
 
+    os.makedirs(args.output_dir, exist_ok=True)
     full_output_path = os.path.join(args.output_dir, args.output_filename)
-    os.makedirs(full_output_path, exist_ok=True)
 
     with open(full_output_path, "w") as file:
         context = Context.default(root=schema, output_stream=file)
