@@ -70,22 +70,17 @@ def summarise(o: JObj, ctx: Context, title_override: str = ""):
             ctx.write(f"- ({type_description}) {path_info}<br>")
         else:
             title: str = title_override or ctx.current_key
-            if ctx.is_required:
-                ctx.write(
-                    f"- {bold(code(quote(title)))} {bold(italic('REQUIRED*'))} ({type_description}) {path_info}<br>"
-                )
-            else:
-                ctx.write(
-                    f"- {bold(code(quote(title)))} ({type_description}) {path_info}<br>"
-                )
+            ctx.write(
+                f"- {bold(code(quote(title)))} {bold(italic('REQUIRED*')) if ctx.is_required else ''} ({type_description}) {path_info}<br>"
+            )
     elif ENUM_TYPE in o:
         ctx.write(
-            f"- {bold(code(quote(ctx.current_key)))} (type: **`Enum`**) {path_info}<br>"
+            f"- {bold(code(quote(ctx.current_key)))} {bold(italic('REQUIRED*')) if ctx.is_required else ''} (type: **`Enum`**) {path_info}<br>"
         )
     elif any(k in o for k in COMPOSITION_KEYS):
         key = next((k for k in COMPOSITION_KEYS if k in o))
         ctx.write(
-            f"- {bold(code(quote(ctx.current_key)))} (type: {bold(code(key.title()))}) {path_info}<br>"
+            f"- {bold(code(quote(ctx.current_key)))} {bold(italic('REQUIRED*')) if ctx.is_required else ''} (type: {bold(code(key.title()))}) {path_info}<br>"
         )
 
     # Defaults
@@ -258,7 +253,9 @@ def parse_oneOrAnyOrAll_of(o: JObj, ctx: Context):
 
     key = next((k for k in COMPOSITION_KEYS if k in o))
 
-    ctx.write(f"***<br>This object can take {key.title()} the following forms:<br>***")
+    ctx.write(
+        f"***<br>This object can take {key.title()} the following forms (total of `{len(o[key])}` variations):<br>***"  # type: ignore
+    )
     ctx.indent().write("[")
     ctx.write_empty()
 
